@@ -25,10 +25,9 @@ build_time_vars = {'ABIFLAGS': '',
  'BYTESTR_DEPS': '\\',
  'CC': 'x86_64-pc-linux-gnu-gcc',
  'CCSHARED': '-fPIC',
- 'CFLAGS': '-fno-strict-overflow -Wsign-compare',
+ 'CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG',
  'CFLAGSFORSHARED': '-fPIC',
  'CFLAGS_ALIASING': '',
- 'CFLAGS_NODIST': '',
  'CODECS_COMMON_HEADERS': './Modules/cjkcodecs/multibytecodec.h '
                           './Modules/cjkcodecs/cjkcodecs.h',
  'COMPILEALL_OPTS': '-j32',
@@ -37,8 +36,9 @@ build_time_vars = {'ABIFLAGS': '',
  'CONFIGURE_CFLAGS': '',
  'CONFIGURE_CFLAGS_NODIST': '-O2 -pipe -march=x86-64-v3 -Werror=odr '
                             '-Werror=lto-type-mismatch -Werror=strict-aliasing '
-                            '-flto -flto -fuse-linker-plugin -ffat-lto-objects '
-                            '-g -std=c11 -Wextra -Wno-unused-parameter '
+                            '-flto -fno-semantic-interposition -flto '
+                            '-fuse-linker-plugin -ffat-lto-objects -g -std=c11 '
+                            '-Wextra -Wno-unused-parameter '
                             '-Wno-missing-field-initializers '
                             '-Wstrict-prototypes '
                             '-Werror=implicit-function-declaration '
@@ -48,7 +48,8 @@ build_time_vars = {'ABIFLAGS': '',
  'CONFIGURE_LDFLAGS_NODIST': '-Wl,-O1 -Wl,--as-needed '
                              '-Wl,-z,pack-relative-relocs -Werror=odr '
                              '-Werror=lto-type-mismatch '
-                             '-Werror=strict-aliasing -flto -flto '
+                             '-Werror=strict-aliasing -flto '
+                             '-fno-semantic-interposition -flto '
                              '-fuse-linker-plugin -ffat-lto-objects -g',
  'CONFIGURE_LDFLAGS_NOLTO': '-fno-lto',
  'CONFIG_ARGS': "'--prefix=/usr' '--build=x86_64-pc-linux-gnu' "
@@ -67,13 +68,18 @@ build_time_vars = {'ABIFLAGS': '',
                 "'--with-system-libmpdec' '--with-platlibdir=lib' "
                 "'--with-pkg-config=yes' "
                 "'--with-wheel-pkg-dir=/usr/lib/python/ensurepip' "
-                "'--with-assertions' '--disable-optimizations' "
+                "'--without-assertions' '--enable-optimizations' "
                 "'--with-readline=readline' '--without-valgrind' '--with-lto' "
                 "'build_alias=x86_64-pc-linux-gnu' "
                 "'host_alias=x86_64-pc-linux-gnu' "
                 "'PKG_CONFIG=x86_64-pc-linux-gnu-pkg-config' "
                 "'PKG_CONFIG_PATH=/usr/share/guile-data/3.0/pkgconfig' "
-                "'CFLAGS=' 'LDFLAGS=' 'CPPFLAGS= -I/usr/include/ncursesw'",
+                "'CFLAGS=' 'LDFLAGS=' 'CPPFLAGS= -I/usr/include/ncursesw' "
+                "'PROFILE_TASK=-m test -j32 --pgo-extended -u-network "
+                '--timeout 1200 -x test_gdb -x test_pretty_print -x '
+                'test_dtrace -x test_asyncio -x test_concurrent_futures -x '
+                'test_httpservers -x test_logging -x test_multiprocessing_fork '
+                "-x test_socket -x test_xmlrpc -x test_tools'",
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python3.12',
  'COREPYTHONPATH': '',
@@ -644,7 +650,6 @@ build_time_vars = {'ABIFLAGS': '',
  'IO_OBJS': '\\',
  'LDCXXSHARED': 'x86_64-pc-linux-gnu-g++ -shared',
  'LDFLAGS': '',
- 'LDFLAGS_NODIST': '',
  'LDLIBRARY': 'libpython3.12.so',
  'LDLIBRARYDIR': '',
  'LDSHARED': 'x86_64-pc-linux-gnu-gcc -shared',
@@ -653,25 +658,27 @@ build_time_vars = {'ABIFLAGS': '',
  'LIBDEST': '/usr/lib/python3.12',
  'LIBDIR': '/usr/lib64',
  'LIBEXPAT_A': 'Modules/expat/libexpat.a',
- 'LIBEXPAT_CFLAGS': '-fno-strict-overflow -Wsign-compare -O2 -pipe '
+ 'LIBEXPAT_CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG -O2 -pipe '
                     '-march=x86-64-v3 -Werror=odr -Werror=lto-type-mismatch '
-                    '-Werror=strict-aliasing -flto -flto -fuse-linker-plugin '
-                    '-ffat-lto-objects -g -std=c11 -Wextra '
-                    '-Wno-unused-parameter -Wno-missing-field-initializers '
-                    '-Wstrict-prototypes -Werror=implicit-function-declaration '
-                    '-fvisibility=hidden  -I./Include/internal -I. -I./Include '
-                    '-I/usr/include/ncursesw -fPIC -fPIC',
+                    '-Werror=strict-aliasing -flto -fno-semantic-interposition '
+                    '-flto -fuse-linker-plugin -ffat-lto-objects -g -std=c11 '
+                    '-Wextra -Wno-unused-parameter '
+                    '-Wno-missing-field-initializers -Wstrict-prototypes '
+                    '-Werror=implicit-function-declaration -fvisibility=hidden '
+                    '-fprofile-use -fprofile-correction -I./Include/internal '
+                    '-I. -I./Include -I/usr/include/ncursesw -fPIC -fPIC',
  'LIBEXPAT_HEADERS': '\\',
  'LIBEXPAT_OBJS': '\\',
  'LIBHACL_CFLAGS': '-I./Modules/_hacl/include -D_BSD_SOURCE -D_DEFAULT_SOURCE '
-                   '-fno-strict-overflow -Wsign-compare -O2 -pipe '
+                   '-fno-strict-overflow -Wsign-compare -DNDEBUG -O2 -pipe '
                    '-march=x86-64-v3 -Werror=odr -Werror=lto-type-mismatch '
-                   '-Werror=strict-aliasing -flto -flto -fuse-linker-plugin '
-                   '-ffat-lto-objects -g -std=c11 -Wextra '
-                   '-Wno-unused-parameter -Wno-missing-field-initializers '
-                   '-Wstrict-prototypes -Werror=implicit-function-declaration '
-                   '-fvisibility=hidden  -I./Include/internal -I. -I./Include '
-                   '-I/usr/include/ncursesw -fPIC -fPIC',
+                   '-Werror=strict-aliasing -flto -fno-semantic-interposition '
+                   '-flto -fuse-linker-plugin -ffat-lto-objects -g -std=c11 '
+                   '-Wextra -Wno-unused-parameter '
+                   '-Wno-missing-field-initializers -Wstrict-prototypes '
+                   '-Werror=implicit-function-declaration -fvisibility=hidden '
+                   '-fprofile-use -fprofile-correction -I./Include/internal '
+                   '-I. -I./Include -I/usr/include/ncursesw -fPIC -fPIC',
  'LIBHACL_HEADERS': '\\',
  'LIBHACL_SHA2_A': 'Modules/_hacl/libHacl_Hash_SHA2.a',
  'LIBHACL_SHA2_HEADERS': '\\',
@@ -679,14 +686,15 @@ build_time_vars = {'ABIFLAGS': '',
  'LIBM': '-lm',
  'LIBMPDEC_A': 'Modules/_decimal/libmpdec/libmpdec.a',
  'LIBMPDEC_CFLAGS': '-DCONFIG_64=1 -DANSI=1 -DHAVE_UINT128_T=1 '
-                    '-fno-strict-overflow -Wsign-compare -O2 -pipe '
+                    '-fno-strict-overflow -Wsign-compare -DNDEBUG -O2 -pipe '
                     '-march=x86-64-v3 -Werror=odr -Werror=lto-type-mismatch '
-                    '-Werror=strict-aliasing -flto -flto -fuse-linker-plugin '
-                    '-ffat-lto-objects -g -std=c11 -Wextra '
-                    '-Wno-unused-parameter -Wno-missing-field-initializers '
-                    '-Wstrict-prototypes -Werror=implicit-function-declaration '
-                    '-fvisibility=hidden  -I./Include/internal -I. -I./Include '
-                    '-I/usr/include/ncursesw -fPIC -fPIC',
+                    '-Werror=strict-aliasing -flto -fno-semantic-interposition '
+                    '-flto -fuse-linker-plugin -ffat-lto-objects -g -std=c11 '
+                    '-Wextra -Wno-unused-parameter '
+                    '-Wno-missing-field-initializers -Wstrict-prototypes '
+                    '-Werror=implicit-function-declaration -fvisibility=hidden '
+                    '-fprofile-use -fprofile-correction -I./Include/internal '
+                    '-I. -I./Include -I/usr/include/ncursesw -fPIC -fPIC',
  'LIBMPDEC_HEADERS': '\\',
  'LIBMPDEC_OBJS': '\\',
  'LIBOBJDIR': 'Python/',
@@ -1012,7 +1020,7 @@ build_time_vars = {'ABIFLAGS': '',
  'MVWDELCH_IS_EXPRESSION': 1,
  'NO_AS_NEEDED': '-Wl,--no-as-needed',
  'OBJECT_OBJS': '\\',
- 'OPT': '',
+ 'OPT': '-DNDEBUG',
  'PACKAGE_BUGREPORT': 0,
  'PACKAGE_NAME': 0,
  'PACKAGE_STRING': 0,
@@ -1028,7 +1036,11 @@ build_time_vars = {'ABIFLAGS': '',
  'PLATLIBDIR': 'lib',
  'POBJS': '\\',
  'POSIX_SEMAPHORES_NOT_ENABLED': 0,
- 'PROFILE_TASK': '-m test --pgo --timeout=1200',
+ 'PROFILE_TASK': '-m test -j32 --pgo-extended -u-network --timeout 1200 -x '
+                 'test_gdb -x test_pretty_print -x test_dtrace -x test_asyncio '
+                 '-x test_concurrent_futures -x test_httpservers -x '
+                 'test_logging -x test_multiprocessing_fork -x test_socket -x '
+                 'test_xmlrpc -x test_tools',
  'PTHREAD_KEY_T_IS_COMPATIBLE_WITH_INT': 1,
  'PTHREAD_SYSTEM_SCHED_SUPPORTED': 1,
  'PURIFY': '',
@@ -1047,60 +1059,69 @@ build_time_vars = {'ABIFLAGS': '',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
  'PY_BUILTIN_HASHLIB_HASHES': '"md5,sha1,sha2,sha3,blake2"',
- 'PY_BUILTIN_MODULE_CFLAGS': '-fno-strict-overflow -Wsign-compare -O2 -pipe '
-                             '-march=x86-64-v3 -Werror=odr '
+ 'PY_BUILTIN_MODULE_CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG -O2 '
+                             '-pipe -march=x86-64-v3 -Werror=odr '
                              '-Werror=lto-type-mismatch '
-                             '-Werror=strict-aliasing -flto -flto '
+                             '-Werror=strict-aliasing -flto '
+                             '-fno-semantic-interposition -flto '
                              '-fuse-linker-plugin -ffat-lto-objects -g '
                              '-std=c11 -Wextra -Wno-unused-parameter '
                              '-Wno-missing-field-initializers '
                              '-Wstrict-prototypes '
                              '-Werror=implicit-function-declaration '
-                             '-fvisibility=hidden  -I./Include/internal -I. '
+                             '-fvisibility=hidden -fprofile-use '
+                             '-fprofile-correction -I./Include/internal -I. '
                              '-I./Include -I/usr/include/ncursesw -fPIC '
                              '-DPy_BUILD_CORE_BUILTIN',
- 'PY_CFLAGS': '-fno-strict-overflow -Wsign-compare',
+ 'PY_CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG',
  'PY_CFLAGS_NODIST': '-O2 -pipe -march=x86-64-v3 -Werror=odr '
                      '-Werror=lto-type-mismatch -Werror=strict-aliasing -flto '
-                     '-flto -fuse-linker-plugin -ffat-lto-objects -g -std=c11 '
-                     '-Wextra -Wno-unused-parameter '
-                     '-Wno-missing-field-initializers -Wstrict-prototypes '
+                     '-fno-semantic-interposition -flto -fuse-linker-plugin '
+                     '-ffat-lto-objects -g -std=c11 -Wextra '
+                     '-Wno-unused-parameter -Wno-missing-field-initializers '
+                     '-Wstrict-prototypes '
                      '-Werror=implicit-function-declaration '
-                     '-fvisibility=hidden  -I./Include/internal',
+                     '-fvisibility=hidden -fprofile-use -fprofile-correction '
+                     '-I./Include/internal',
  'PY_COERCE_C_LOCALE': 1,
- 'PY_CORE_CFLAGS': '-fno-strict-overflow -Wsign-compare -O2 -pipe '
+ 'PY_CORE_CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG -O2 -pipe '
                    '-march=x86-64-v3 -Werror=odr -Werror=lto-type-mismatch '
-                   '-Werror=strict-aliasing -flto -flto -fuse-linker-plugin '
-                   '-ffat-lto-objects -g -std=c11 -Wextra '
-                   '-Wno-unused-parameter -Wno-missing-field-initializers '
-                   '-Wstrict-prototypes -Werror=implicit-function-declaration '
-                   '-fvisibility=hidden  -I./Include/internal -I. -I./Include '
-                   '-I/usr/include/ncursesw -fPIC -DPy_BUILD_CORE',
+                   '-Werror=strict-aliasing -flto -fno-semantic-interposition '
+                   '-flto -fuse-linker-plugin -ffat-lto-objects -g -std=c11 '
+                   '-Wextra -Wno-unused-parameter '
+                   '-Wno-missing-field-initializers -Wstrict-prototypes '
+                   '-Werror=implicit-function-declaration -fvisibility=hidden '
+                   '-fprofile-use -fprofile-correction -I./Include/internal '
+                   '-I. -I./Include -I/usr/include/ncursesw -fPIC '
+                   '-DPy_BUILD_CORE',
  'PY_CORE_LDFLAGS': '-Wl,-O1 -Wl,--as-needed -Wl,-z,pack-relative-relocs '
                     '-Werror=odr -Werror=lto-type-mismatch '
-                    '-Werror=strict-aliasing -flto -flto -fuse-linker-plugin '
-                    '-ffat-lto-objects -g',
+                    '-Werror=strict-aliasing -flto -fno-semantic-interposition '
+                    '-flto -fuse-linker-plugin -ffat-lto-objects -g',
  'PY_CPPFLAGS': '-I. -I./Include -I/usr/include/ncursesw',
  'PY_ENABLE_SHARED': 1,
  'PY_HAVE_PERF_TRAMPOLINE': 1,
  'PY_LDFLAGS': '',
  'PY_LDFLAGS_NODIST': '-Wl,-O1 -Wl,--as-needed -Wl,-z,pack-relative-relocs '
                       '-Werror=odr -Werror=lto-type-mismatch '
-                      '-Werror=strict-aliasing -flto -flto -fuse-linker-plugin '
+                      '-Werror=strict-aliasing -flto '
+                      '-fno-semantic-interposition -flto -fuse-linker-plugin '
                       '-ffat-lto-objects -g',
  'PY_LDFLAGS_NOLTO': '-fno-lto',
  'PY_SQLITE_ENABLE_LOAD_EXTENSION': 1,
  'PY_SQLITE_HAVE_SERIALIZE': 1,
  'PY_SSL_DEFAULT_CIPHERS': 1,
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
- 'PY_STDMODULE_CFLAGS': '-fno-strict-overflow -Wsign-compare -O2 -pipe '
-                        '-march=x86-64-v3 -Werror=odr '
+ 'PY_STDMODULE_CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG -O2 '
+                        '-pipe -march=x86-64-v3 -Werror=odr '
                         '-Werror=lto-type-mismatch -Werror=strict-aliasing '
-                        '-flto -flto -fuse-linker-plugin -ffat-lto-objects -g '
-                        '-std=c11 -Wextra -Wno-unused-parameter '
+                        '-flto -fno-semantic-interposition -flto '
+                        '-fuse-linker-plugin -ffat-lto-objects -g -std=c11 '
+                        '-Wextra -Wno-unused-parameter '
                         '-Wno-missing-field-initializers -Wstrict-prototypes '
                         '-Werror=implicit-function-declaration '
-                        '-fvisibility=hidden  -I./Include/internal -I. '
+                        '-fvisibility=hidden -fprofile-use '
+                        '-fprofile-correction -I./Include/internal -I. '
                         '-I./Include -I/usr/include/ncursesw -fPIC',
  'PY_SUPPORT_TIER': 1,
  'Py_DEBUG': 0,
